<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Session;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\Validator;

class AuthController extends Controller
{
    use ConsumeExternalService;

    /*
    |--------------------------------------------------------------------------
    | GET LOGIN PAGE 
    |--------------------------------------------------------------------------
    */

    public function login()
    {
       
        $userToken = session()->get('USER_TOKEN');

        if ($userToken !== null) {
            return redirect()->back();
        } else {
            return view('user.auth.login');
        }
    }

    /*
    |--------------------------------------------------------------------------
    | LOGIN API
    |--------------------------------------------------------------------------
    */

    public function loginPost(Request $request)
    {
        $rules = [
            'email'     =>  'required',
            'password'  =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';

        if ($validator->fails()) {
            return redirect()->back()->with('error', $errorMsg);
        }

        $post_data = array(
            "email" => $request->email,
            "password" => $request->password,
            'device_token' => '0',
            'device_type' => 'W',
        );

        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("get", "/api/v1/auth/login", $data);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', $response_decoded->message);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $profile_res = $this->performRequest("GET", "/api/v1/auth/userprofile", [], ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($response_decoded->data->devicedetails->token)]);
            $profile_decoded = json_decode(EncryptDecrypt::bodyDecrypt($profile_res));

            if (!empty($profile_decoded) && ($profile_decoded->code == 0 || $profile_decoded->code == '0')) {
                return redirect()->back()->with('error', 'Something Went Wrong');
            } elseif (!empty($profile_decoded) && ($profile_decoded->code == 1 || $profile_decoded->code == '1')) {
                $user_data = $profile_decoded->data;
                session()->put('USER_LOGIN_SESSION', $user_data->userdetails);
                session()->put('USER_TOKEN', $user_data->devicedetails->token);
                return redirect()->route('dashboard');
            }
        }
    }


    /*
    |--------------------------------------------------------------------------
    | GET SIGNUP PAGE
    |--------------------------------------------------------------------------
    */

    public function signup()
    {
        return view('user.auth.signup');
    }

    /*
    |--------------------------------------------------------------------------
    | SIGNUP API
    |--------------------------------------------------------------------------
    */

    public function signupPost(Request $request)
    {
        $rules = [
            'name'     =>  'required',
            'mobile_code'  =>  'required',
            'phone'  =>  'required',
            'email'  =>  'required',
            'password'  =>  'required',
            'c_password'  =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return redirect()->back()->with('error', $errorMsg);
        }

        $post_data = array(
            'name' => $request->name,
            'country_code_id' => $request->mobile_code,
            'phone_number' => $request->phone,
            'email' => $request->email,
            'password' => $request->password,
            'device_token' => '0',
            'device_type' => 'w',
        );

        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/auth/signup", $data);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', $response_decoded->message);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $user_data = $response_decoded->data;
            session()->put('USER_LOGIN_SESSION', $user_data->userdetails);
            session()->put('USER_TOKEN', $user_data->devicedetails->token);

            return redirect()->route('otp_verify');
        }
    }


    /*
    |--------------------------------------------------------------------------
    | GET OTP VERIFICATION PAGE
    |--------------------------------------------------------------------------
    */

    public function getOtpVerification()
    {
        return view('user.auth.otp_verify');
    }


    /*
    |--------------------------------------------------------------------------
    | VERIFY OTP API
    |--------------------------------------------------------------------------
    */

    public function postOtpVerification(Request $request)
    {

        $email = session()->get('email');
        $user_data = session()->get('USER_LOGIN_SESSION');
  
        $is_forgot = session()->get('is_forgot');

        $rules = [
            'otp'  =>  'required',
        ];

        $requestData = $request->only(['otp']);

        $validator = Validator::make($requestData, $rules);
        $errorMsg = 'Oops! Something went wrong.';

        if ($validator->fails()) {
            return redirect()->back()->with('error', $errorMsg);
        }

        if (session()->has('USER_LOGIN_SESSION')) {
            $post_data = array(
                'email' => $user_data->email,
                'otp' => $request->otp,
            );
        } else {
            $post_data = array(
                'email' => $email,
                'otp' => $request->otp,
            );
        }

        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/auth/verifyotp", $data);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', $response_decoded->message);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            if ($is_forgot == 1) {
                return redirect()->route('reset_password');
            } else {
                return redirect()->route('dashboard');
            }
        }
    }


    /*
    |--------------------------------------------------------------------------
    | FORGOT
    |--------------------------------------------------------------------------
    */

    public function forgot(Request $request)
    {

        session()->put('is_forgot', '1');
        session()->put('email', $request->forgot_email);

        $post_data = array(
            "email" => $request->forgot_email,
        );

        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/auth/forgot_password", $data);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if ($response_decoded->code == 1) {
            return redirect()->route('otp_verify');
        } else {
            return redirect()->back()->with('error', $response_decoded->message);
        }
    }

    /*
    |--------------------------------------------------------------------------
    | GET RESET PASSWORD PAGE
    |--------------------------------------------------------------------------
    */

    public function reset_password(Request $request)
    {
        session()->put('is_forgot', '0');
        return view('user.auth.reset_password');
    }

    /*
    |--------------------------------------------------------------------------
    | RESET PASSWORD API
    |--------------------------------------------------------------------------
    */

    public function set_password(Request $request)
    {
        $email = session()->get('email');

        $post_data = array(
            "email" => $email,
            'new_password' => $request->password,
        );

        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/auth/set_password", $data);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if ($response_decoded->code == 1) {
            return redirect()->route('user.login')->with('success', $response_decoded->message);
        } else {
            return redirect()->back()->with('error', $response_decoded->message);
        }
    }
}
