<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\View;

class BlogController extends Controller
{
    use ConsumeExternalService;


    public function blog()
    {
        $userToken = session()->get('USER_TOKEN');
        // dd($userToken);
        if ($userToken) {
            $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
            $response = $this->performRequest("GET", "/api/v1/user/allBloglisting", [], $formParams);
            $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
            // dd($response_decoded);

            if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
                $data = null;
            } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
                $data = $response_decoded->data;
            }
            return view('user.blog.blog', compact('data'));
        } else {
            return redirect()->route('user.login');
        }
    }


    public function readBlog(Request $request, $id)
    {
        $userToken = session()->get('USER_TOKEN');
        $blog_id = base64_decode($id);

        $post_data = array(
            'blog_id' => $blog_id,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("get", "/api/v1/user/viewBlog", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            $data = $response_decoded->data[0];

            $other_blogs_response = $this->performRequest("GET", "/api/v1/user/allBloglisting", [], $formParams);
            $other_blogs_response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($other_blogs_response));
            // dd($response_decoded);

            if (!empty($other_blogs_response_decoded) && ($other_blogs_response_decoded->code == 0 || $other_blogs_response_decoded->code == '0')) {
                $other_blogs = null;
            } elseif (!empty($other_blogs_response_decoded) && ($other_blogs_response_decoded->code == 1 || $other_blogs_response_decoded->code == '1')) {
                $other_blogs = $other_blogs_response_decoded->data;
            }
            return view('user.blog.blog-read-more', compact('data','other_blogs'));
        }
    }

    public function searchBlog(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $post_data = array(
            'search' => $request->search,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("get", "/api/v1/user/searchBlog", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            $data = null;
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            $data = $response_decoded->data;
            // dd($data);   
        }

        $html = View::make('user.blog.search-blog', compact('data'))->render();
        return response()->json(['status' => true, 'content' => $html]);
    }
}
