<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\Validator;
use App\Helpers\EncryptDecrypt;

class ContactTypeController extends Controller
{
    use ConsumeExternalService;

    /*
    |--------------------------------------------------------------------------
    | ADD CONTACT TYPE API
    |--------------------------------------------------------------------------
    */

    public function addContactType(Request $request)
    {

        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'contact_type' =>  'required',
            'color'  =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'name' => $request->contact_type,
            'color' => $request->color,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/addNewType", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Contact Type added Successfully']);
        }
    }

    /*
    |--------------------------------------------------------------------------
    | RENAME CONTACT TYPE API
    |--------------------------------------------------------------------------
    */

    public function renameContactType(Request $request)
    {
        // dd($request->all());
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'contact_type_id' =>  'required',
            'rename_type'  =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'id' => $request->contact_type_id,
            'name' => $request->rename_type,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/renameType", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Contact Type renamed Successfully']);
        }
    }

    /*
    |--------------------------------------------------------------------------
    | DELETE CONTACT TYPE API
    |--------------------------------------------------------------------------
    */

    public function deleteContactType(Request $request)
    {
        // dd($request->all());
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'contactId' =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'id' => $request->contactId,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/deleteType", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Contact Type deleted Successfully']);
        }
    }
}
