<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\Validator;


class DailyPlanController extends Controller
{
    use ConsumeExternalService;

    public function addDailyTask(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'title' =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'title' => $request->title,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/addDailyPlan", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $daily_plan_res = $this->performRequest("get", "/api/v1/user/dailyPlanListing", null, $formParams);
            $daily_plan_decoded = json_decode(EncryptDecrypt::bodyDecrypt($daily_plan_res));
            if (!empty($daily_plan_decoded) && ($daily_plan_decoded->code == 0 || $daily_plan_decoded->code == '0')) {
                $daily_plan_list = null;
            } elseif (!empty($daily_plan_decoded) && ($daily_plan_decoded->code == 1 || $daily_plan_decoded->code == '1')) {
                $daily_plan_list = $daily_plan_decoded->data;
            }

            session()->put('DAILY_PLAN_LIST_SESSION', $daily_plan_list);
            return response()->json(['status' => 'success', 'message' => 'Task added Successfully']);
        }
    }

    public function editDailyTask(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'task_id' =>  'required',
            'task_title' =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'plan_id' => $request->task_id,
            'title' => $request->task_title,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/updateDailyPlan", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $daily_plan_res = $this->performRequest("get", "/api/v1/user/dailyPlanListing", null, $formParams);
            $daily_plan_decoded = json_decode(EncryptDecrypt::bodyDecrypt($daily_plan_res));
            if (!empty($daily_plan_decoded) && ($daily_plan_decoded->code == 0 || $daily_plan_decoded->code == '0')) {
                $daily_plan_list = null;
            } elseif (!empty($daily_plan_decoded) && ($daily_plan_decoded->code == 1 || $daily_plan_decoded->code == '1')) {
                $daily_plan_list = $daily_plan_decoded->data;
            }

            session()->put('DAILY_PLAN_LIST_SESSION', $daily_plan_list);

            return response()->json(['status' => 'success', 'message' => 'Task updated Successfully']);
        }
    }

    public function deleteDailyTask(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'task_id' =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'plan_id' => $request->task_id,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("get", "/api/v1/user/deleteDailyPlan", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $daily_plan_res = $this->performRequest("get", "/api/v1/user/dailyPlanListing", null, $formParams);
            $daily_plan_decoded = json_decode(EncryptDecrypt::bodyDecrypt($daily_plan_res));
            if (!empty($daily_plan_decoded) && ($daily_plan_decoded->code == 0 || $daily_plan_decoded->code == '0')) {
                $daily_plan_list = null;
            } elseif (!empty($daily_plan_decoded) && ($daily_plan_decoded->code == 1 || $daily_plan_decoded->code == '1')) {
                $daily_plan_list = $daily_plan_decoded->data;
            }

            session()->put('DAILY_PLAN_LIST_SESSION', $daily_plan_list);

            return response()->json(['status' => 'success', 'message' => 'Task Deleted Successfully']);
        }
    }

    public function completeDailyTask(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'task_id' =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'plan_id' => $request->task_id,
            'is_completed' => '1',
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/completeDailyPlan", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $daily_plan_res = $this->performRequest("get", "/api/v1/user/dailyPlanListing", null, $formParams);
            $daily_plan_decoded = json_decode(EncryptDecrypt::bodyDecrypt($daily_plan_res));
            if (!empty($daily_plan_decoded) && ($daily_plan_decoded->code == 0 || $daily_plan_decoded->code == '0')) {
                $daily_plan_list = null;
            } elseif (!empty($daily_plan_decoded) && ($daily_plan_decoded->code == 1 || $daily_plan_decoded->code == '1')) {
                $daily_plan_list = $daily_plan_decoded->data;
            }

            session()->put('DAILY_PLAN_LIST_SESSION', $daily_plan_list);

            return response()->json(['status' => 'success', 'message' => 'Task Completed Successfully']);
        }
    }
}
