<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\Validator;

class FollowUpController extends Controller
{
    use ConsumeExternalService;

    public function createFollowUp(Request $request)
    {
        // dd($request->all());
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'followUpContactId'     =>  'required',
            'selectedFollowUpDate'  =>  'required',
            'follow_up_notes'  =>  'nullable',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'contact_id' => $request->followUpContactId,
            'date' => $request->selectedFollowUpDate,
            'notes' => $request->follow_up_notes,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/addFollowup", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Follow Up Added Successfully.']);
        }
    }

    public function deleteFollowUp(Request $request)
    {

        $userToken = session()->get('USER_TOKEN');

        $post_data = array(
            'followup_id' => $request->followup_id,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/deleteFollowup", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Follow Up Deleted Successfully.']);
        }
    }

    public function markFollowupComplete(Request $request)
    {
        // dd($request->all());
        $userToken = session()->get('USER_TOKEN');

        $post_data = array(
            'followup_id' => $request->complete_followup_id,
            'note' => $request->followup_completed_note,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/completeFollowupNote", $data, $formParams);
        // dd($response);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
// dd($response_decoded);
        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Follow Up Completed Successfully.']);
        }
    }


}
