<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Session;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Carbon\Carbon;
use Illuminate\Support\Facades\View;

class LoggedConnectionController extends Controller
{
    use ConsumeExternalService;


    public function loggedConnection(Request $request)
    {
        
        $userToken = session()->get('USER_TOKEN');
        
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $response = $this->performRequest("get", "/api/v1/user/loggedConnections", null, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);
        
      if (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $data = $response_decoded->data;
            // dd($data);
            // dd($jsonData);
            // Add a flag to each followup
            $followups = collect($data->followups)->map(function ($followup) {
                $followup->type_flag = 'Followup';  // Add a type_flag property
                return $followup;
            });

            // Add a flag to each meeting
            $meetings = collect($data->meetings)->map(function ($meeting) {
                $meeting->type_flag = 'Meeting';  // Add a type_flag property
                return $meeting;
            });

            // Merge the collections with flags
            $allItems = $followups->merge($meetings);

            // Group all items by the date found in 'created_at' and sort them
            $groupedItems = $allItems->groupBy(function ($item) {
                return Carbon::parse($item->created_at)->format('Y-m-d'); // Group by date only
            })->sortByDesc(function ($item, $key) {
                return $key; // Sort groups by date in descending order
            });

            // dd($groupedItems);
            return view('user.logged_connection.logged_connection', compact('groupedItems'));
        } else{
            $groupedItems = null;

            return view('user.logged_connection.logged_connection', compact('groupedItems'));
        }

    }

    public function filterConnection(Request $request)
    {
        // dd($request->all());

        $userToken = session()->get('USER_TOKEN');
        $filter_no = $request->input('filter_no');
        $filterDate = $request->input('date');


        $post_data = array(
            'filter_no' => $filter_no,
            'date' => $filterDate,
        );

        // dd($post_data);

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("get", "/api/v1/user/loggedConnections", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

       if (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $data = $response_decoded->data;
            // dd($data);

            if ($filter_no == 1 || $filter_no == '1') {
                $followups = collect($data)->map(function ($item) {
                    $item->type_flag = 'Followup';
                    $item->created_at = $item->contact_create;
                    return $item;
                });
            } else {
                $meetings = collect($data)->map(function ($item) {
                    $item->type_flag = 'Meeting';  // Add a type_flag property
                    return $item;
                });
            }
            // dd($data);


            // Group all items by the date found in 'created_at' and sort them
            $groupedItems = collect($data)->groupBy(function ($item) {
                return Carbon::parse($item->created_at)->format('Y-m-d'); // Group by date only
            })->sortByDesc(function ($item, $key) {
                return $key; // Sort groups by date in descending order
            });
            // dd($groupedItems);

            $html = View::make('user.logged_connection.filter_data', compact('groupedItems'))->render();
            return response()->json(['status' => true, 'content' => $html]);
        }
    }

    public function deleteLoggedConnection(Request $request)
    {
        // dd($request->all());
        $userToken = session()->get('USER_TOKEN');

        $post_data = array(
            'label' => 'client',
            'contact_id' => $request->contact_id,
            'meeting_id' => $request->contact_id,
            'followup_id' => $request->contact_id,
        );
// dd($post_data);
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("get", "/api/v1/user/deleteLogged", $data, $formParams);
        // dd($response);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
dd($response_decoded);
        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', $response_decoded->message);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $data = $response_decoded->data;
        }
    }
}
