<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\Validator;
use App\Helpers\EncryptDecrypt;

class MeetingController extends Controller
{
    use ConsumeExternalService;

    /*
    |--------------------------------------------------------------------------
    | CREATE MEETING API
    |--------------------------------------------------------------------------
    */

    public function createMeeting(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'contact_id'     =>  'required',
            'meeting_date'  =>  'required',
            'meeting_time'  =>  'required',
            'meeting_link'  =>  'required',
            'meeting_notes'  =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }


        $post_data = array(
            'contact_id' => $request->contact_id,
            'notes' => $request->meeting_notes,
            'date' => $request->meeting_date,
            'time' => $request->meeting_time,
            'link' => $request->meeting_link,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/addMeeting", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Meeting Scheduled Successfully.']);
        }
    }

    /*
    |--------------------------------------------------------------------------
    | DELETE MEETING API
    |--------------------------------------------------------------------------
    */

    public function deleteMeeting(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $post_data = array(
            'meeting_id' => $request->contactId,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/deleteMeeting", $data, $formParams);
        // dd($response);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', $response_decoded->message);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['success' => true]);
        }
    }

    /*
    |--------------------------------------------------------------------------
    | ADD MEETING NOTES API
    |--------------------------------------------------------------------------
    */

    public function markMeetingComplete(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'meeting_id'     =>  'required',
            'meeting_notes'  =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'meeting_id' => $request->meeting_id,
            'note' => $request->meeting_notes,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/completeMeetingNote", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Meeting Completed added Successfully']);
        }
    }
}
