<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Session;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\View;

class MyContactController extends Controller
{
    use ConsumeExternalService;

    /*
    |--------------------------------------------------------------------------
    | IT WILL FETCH CONTACT-LISTING && CONTACT-TYPE-LISTING
    |--------------------------------------------------------------------------
    */

    public function myContact()
    {
        $userToken = session()->get('USER_TOKEN');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $response = $this->performRequest("get", "/api/v1/user/getAllContacts", null, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            $data = null;
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            $data = $response_decoded->data;
        }

        $contact_type_res = $this->performRequest("get", "http://13.235.173.222:9999/api/v1/user/contactType", null, $formParams);
        $contact_type_decoded = json_decode(EncryptDecrypt::bodyDecrypt($contact_type_res));

        if (!empty($contact_type_decoded) && ($contact_type_decoded->code == 0 || $contact_type_decoded->code == '0')) {
            $contact_type = null;
        } elseif (!empty($contact_type_decoded) && ($contact_type_decoded->code == 1 || $contact_type_decoded->code == '1')) {
            $contact_type = $contact_type_decoded->data;
        }
        // dd($contact_type);
        return view('user.my_contact.my_contact', compact('data', 'contact_type'));
    }

    /*
    |--------------------------------------------------------------------------
    | ADD CONTACT API
    |--------------------------------------------------------------------------
    */

    public function addContact(Request $request)
    {
        // dd($request->all());
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'type'     =>  'required',
            'first_name'  =>  'required',
            'last_name'  =>  'required',
            'email'  =>  'required',
            'mobile_code'  =>  'required',
            'phone_number'  =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return redirect()->back()->with('error', $errorMsg);
        }

        $post_data = array(
            'firstname' => $request->first_name,
            'lastname' => $request->last_name,
            'email' => $request->email,
            'country_code' => $request->mobile_code,
            'phone_number' => $request->phone_number,
            'type' => $request->type,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/addContact", $data, $formParams);
        // dd($response);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', $response_decoded->message);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return redirect()->route('my_contact');
        }
    }

    /*
    |--------------------------------------------------------------------------
    | DELETE CONTACT API
    |--------------------------------------------------------------------------
    */

    public function deleteContact(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $post_data = array(
            'contact_id' => $request->contactId,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/deleteContact", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', $response_decoded->message);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['success' => true]);
        }
    }

    /*
    |--------------------------------------------------------------------------
    | VIEW CONTACT API
    |--------------------------------------------------------------------------
    */

    public function viewContact(Request $request)
    {

        $userToken = session()->get('USER_TOKEN');

        $post_data = array(
            'contact_id' => $request->contact_id,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        //------------  THIS API IS USED TO  GET DETAILS OF PARTICULAR CONTACT --------------//
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/viewContact", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        //------------  THIS API IS USED TO GET THE LISTING OF LANGUAGES DYNAMICALLY --------------//
        $lang_list_res = $this->performRequest("GET", "/api/v1/user/languageListing", [], $formParams);
        $lang_list_decoded = json_decode(EncryptDecrypt::bodyDecrypt($lang_list_res));

        if (!empty($lang_list_decoded) && ($lang_list_decoded->code == 0 || $lang_list_decoded->code == '0')) {
            $lang_list = null;
        } elseif (!empty($lang_list_decoded) && ($lang_list_decoded->code == 1 || $lang_list_decoded->code == '1')) {
            $lang_list = $lang_list_decoded->data;
        }

        //------------  THIS API IS USED TO GET THE LISTING OF CONTACT TYPE DYNAMICALLY --------------//
        $contact_type_list_res = $this->performRequest("GET", "/api/v1/user/contactType", [], $formParams);
        $contact_type_list_decoded = json_decode(EncryptDecrypt::bodyDecrypt($contact_type_list_res));
        if (!empty($contact_type_list_decoded) && ($contact_type_list_decoded->code == 0 || $contact_type_list_decoded->code == '0')) {
            $contact_type_list = null;
        } elseif (!empty($contact_type_list_decoded) && ($contact_type_list_decoded->code == 1 || $contact_type_list_decoded->code == '1')) {
            $contact_type_list = $contact_type_list_decoded->data;
        }

        //------------  THIS API IS USED TO GET THE LISTING OF TIMZONE DYNAMICALLY --------------//
        $timezone_list_res = $this->performRequest("POST", "/api/v1/user/timeZoneListing", null, $formParams);
        $timezone_list_decoded = json_decode(EncryptDecrypt::bodyDecrypt($timezone_list_res));

        if (!empty($timezone_list_decoded) && ($timezone_list_decoded->code == 0 || $timezone_list_decoded->code == '0')) {
            $timezone_list = null;
        } elseif (!empty($timezone_list_decoded) && ($timezone_list_decoded->code == 1 || $timezone_list_decoded->code == '1')) {
            $timezone_list = $timezone_list_decoded->data;
        }

        //------------  THIS API IS USED TO GET THE LISTING OF LANGUAGES DYNAMICALLY --------------//
        $social_media_list_res = $this->performRequest("GET", "/api/v1/user/socialMediaListing", [], $formParams);
        $social_media_list_decoded = json_decode(EncryptDecrypt::bodyDecrypt($social_media_list_res));
        // dd($social_media_list_decoded);
        if (!empty($social_media_list_decoded) && ($social_media_list_decoded->code == 0 || $social_media_list_decoded->code == '0')) {
            $social_media_list = null;
        } elseif (!empty($social_media_list_decoded) && ($social_media_list_decoded->code == 1 || $social_media_list_decoded->code == '1')) {
            $social_media_list = $social_media_list_decoded->data;
            session()->put('SOCIAL_MEDIA_LIST', $social_media_list);
        }


        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', $response_decoded->message);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            $contactDetails = $response_decoded->data->details[0]; // GET THE CONTACT DETAILS
            // dd($contactDetails);
            $socialMediaDetails = $response_decoded->data->socialMedia; // GET SOCIAL MEDIA DETAILS

            $html = View::make('user.dashboard.view_contact', compact('contactDetails', 'socialMediaDetails', 'lang_list', 'timezone_list', 'social_media_list', 'contact_type_list'))->render();
            return response()->json(['status' => true, 'content' => $html]);
        }
    }

    /*
    |--------------------------------------------------------------------------
    | UPDATE CONTACT API
    |--------------------------------------------------------------------------
    */

    public function updateContact(Request $request)
    {

        // dd($request->all());
        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'contact_id'     =>  'required',
            'firstname'  =>  'required',
            'lastname'  =>  'required',
            'compnay_name'  =>  'required',
            'type'  =>  'required',
            'email'  =>  'required',
            'alternate_email'  =>  'required',
            'address'  =>  'required',
            'phone_number'  =>  'required',
            'additional_phone_number'  =>  'required',
            'contact_method'  =>  'required',
            'language'  =>  'required',
            'timezone'  =>  'required',
            

        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json(['status' => 'error', 'message' => $errorMsg]);
        }

        $post_data = array(
            'contact_id' => $request->contact_id,
            'firstname' => $request->firstname,
            'lastname' => $request->lastname,
            'compnay_name' => $request->compnay_name,
            'type' => $request->type,
            'email' => $request->email,
            'alternate_email' => $request->alternate_email,
            'address' => $request->address,
            'country_code_id' => '+91',
            'phone_number' => $request->phone_number,
            'additional_phone_number' => $request->additional_phone_number,
            'contact_method' => $request->contact_method,
            'language_id' => $request->language,
            'timezone_id' => $request->timezone,
            
        );

        // dd($post_data);
        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        //------------  THIS API IS USED TO GET DETAILS OF PARTICULAR CONTACT --------------//
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/updateContact", $data, $formParams);
        // dd($response);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
        // dd($response_decoded);

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            return response()->json(['status' => 'success', 'message' => "Contact Details Updated Successfully"]);
        }
    }
}
