<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Session;
use App\Helpers\EncryptDecrypt;
use App\Traits\ConsumeExternalService;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Facades\Validator;

class SettingController extends Controller
{
    use ConsumeExternalService;


    public function setting()
    {
        return view('user.setting.setting');
    }


    public function setting_page(Request $request)
    {

        if ($request->types == "referral_program") {
            $html = View::make('user.setting.referral_program')->render();
            return response()->json(['status' => true, 'content' => $html]);
        }

        if ($request->types == "ambassador_program") {
            $html = View::make('user.setting.ambassador_program')->render();
            return response()->json(['status' => true, 'content' => $html]);
        }

        if ($request->types == "bank_info") {
            $html = View::make('user.setting.bank_info')->render();
            return response()->json(['status' => true, 'content' => $html]);
        }
        if ($request->types == "subscription") {
            $html = View::make('user.setting.subscription')->render();
            return response()->json(['status' => true, 'content' => $html]);
        }

        if ($request->types == "about_us") {
            $html = View::make('user.setting.about_us')->render();
            return response()->json(['status' => true, 'content' => $html]);
        }

        if ($request->types == "term_and_condition") {
            $html = View::make('user.setting.term_and_condition')->render();
            return response()->json(['status' => true, 'content' => $html]);
        }

        if ($request->types == "privacy") {
            $html = View::make('user.setting.privacy_policy')->render();
            return response()->json(['status' => true, 'content' => $html]);
        }


        if ($request->types == "contact_us") {
            $html = View::make('user.setting.contact_us')->render();
            return response()->json(['status' => true, 'content' => $html]);
        }
    }


    public function change_password(Request $request)
    {

        $html = View::make('user.setting.change_password')->render();
        return response()->json(['status' => true, 'content' => $html]);
    }

    public function change_password_post(Request $request)
    {
        $userToken = Session::get('user_token');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];

        $post_data = array(
            "old_password" => $request->old_password,
            "new_password" => $request->new_password,
        );

        // dd($post_data);

        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/auth/changePassword", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        // dd($response_decoded);


        if ($response_decoded->code !== 1) {
            return redirect()->back()->with('error', $response_decoded->message);
        } else {
            return redirect()->back()->with('success', $response_decoded->message);
        }
    }

    public function logout(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $response = $this->performRequest("POST", "/api/v1/auth/logout", null, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));


        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return redirect()->back()->with('error', 'Something Went Wrong');
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {

            session()->forget('USER_LOGIN_SESSION');
            session()->forget('USER_TOKEN');
            $output['url'] = route('user.login');
            return response()->json($output);
        }
    }

    public function contactUs(Request $request)
    {

        $userToken = session()->get('USER_TOKEN');

        $rules = [
            'fullname' =>  'required',
            'phone_number'  =>  'required',
            'description'  =>  'required',
        ];

        $validator = Validator::make($request->all(), $rules);
        $errorMsg = 'Oops! Somthing went wrong.';
        if ($validator->fails()) {
            return response()->json([
                'status' => 'error',
                'message' => $errorMsg,
                'errors' => $validator->errors()
            ]);
        }

        $post_data = array(
            'fullname' => $request->fullname,
            'phone_number' => $request->phone_number,
            'description' => $request->description,
        );

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $data = EncryptDecrypt::bodyEncrypt(json_encode($post_data));
        $response = $this->performRequest("POST", "/api/v1/user/contactUs", $data, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));
      
        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            return response()->json(['status' => 'error', 'message' => $response_decoded->message]);
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            return response()->json(['status' => 'success', 'message' => 'Your record has been submitted successfully.']);
        }
    }


    public function faq(Request $request)
    {
        $userToken = session()->get('USER_TOKEN');

        $formParams = ['app' => 'U', 'token' => EncryptDecrypt::bodyEncrypt($userToken)];
        $response = $this->performRequest("POST", "/api/v1/user/allFaqs", null, $formParams);
        $response_decoded = json_decode(EncryptDecrypt::bodyDecrypt($response));

        if (!empty($response_decoded) && ($response_decoded->code == 0 || $response_decoded->code == '0')) {
            $data = null;
        } elseif (!empty($response_decoded) && ($response_decoded->code == 1 || $response_decoded->code == '1')) {
            $data = $response_decoded->data;
        }
        return view('user.faq',compact('data'));
    }
}
