<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', [App\Http\Controllers\User\HomeController::class, 'index'])->name('index');



Route::get('login', [App\Http\Controllers\User\AuthController::class, 'login'])->name('user.login');
Route::post('login', [App\Http\Controllers\User\AuthController::class, 'loginPost'])->name('user.loginPost');


Route::get('signup', [App\Http\Controllers\User\AuthController::class, 'signup'])->name('user.signup');
Route::post('signup-post', [App\Http\Controllers\User\AuthController::class, 'signupPost'])->name('user.signupPost');

Route::get('verification', [App\Http\Controllers\User\AuthController::class, 'getOtpVerification'])->name('otp_verify');
Route::post('verification', [App\Http\Controllers\User\AuthController::class, 'postOtpVerification'])->name('verify_post');


Route::post('forgot', [App\Http\Controllers\User\AuthController::class, 'forgot'])->name('forgot');
Route::get('reset-password', [App\Http\Controllers\User\AuthController::class, 'reset_password'])->name('reset_password');
Route::post('set-password', [App\Http\Controllers\User\AuthController::class, 'set_password'])->name('set_password');




Route::middleware(['checkLogin'])->group(function () {

     //DASHBOARD ROUTES
     Route::get('dashboard', [App\Http\Controllers\User\DashboardController::class, 'dashboard'])->name('dashboard');


     //MY CONTACTS ROUTES
     Route::get('my-contacts', [App\Http\Controllers\User\MyContactController::class, 'myContact'])->name('my_contact');
     Route::post('add-contact', [App\Http\Controllers\User\MyContactController::class, 'addContact'])->name('addContact');
     Route::post('delete-contact', [App\Http\Controllers\User\MyContactController::class, 'deleteContact'])->name('deleteContact');
     Route::post('view-contact', [App\Http\Controllers\User\MyContactController::class, 'viewContact'])->name('viewContact');
     Route::post('update-contact', [App\Http\Controllers\User\MyContactController::class, 'updateContact'])->name('updateContact');


     //MEETING ROUTES
     Route::post('create-meeting', [App\Http\Controllers\User\MeetingController::class, 'createMeeting'])->name('createMeeting');
     Route::post('delete-meeting', [App\Http\Controllers\User\MeetingController::class, 'deleteMeeting'])->name('deleteMeeting');
     Route::post('mark-meeting-complete', [App\Http\Controllers\User\MeetingController::class, 'markMeetingComplete'])->name('markMeetingComplete');
    
     //FOLLOW UP ROUTES
     Route::post('create-followup', [App\Http\Controllers\User\FollowUpController::class, 'createFollowUp'])->name('createFollowUp');
     Route::post('delete-followup', [App\Http\Controllers\User\FollowUpController::class, 'deleteFollowUp'])->name('deleteFollowUp');
     Route::post('mark-followup-complete', [App\Http\Controllers\User\FollowUpController::class, 'markFollowupComplete'])->name('markFollowupComplete');


     //CONTACT TYPE ROUTES
     Route::post('add-contact-type', [App\Http\Controllers\User\ContactTypeController::class, 'addContactType'])->name('addContactType');
     Route::post('rename-contact-type', [App\Http\Controllers\User\ContactTypeController::class, 'renameContactType'])->name('renameContactType');
     Route::post('delete-contact-type', [App\Http\Controllers\User\ContactTypeController::class, 'deleteContactType'])->name('deleteContactType');

     //LOG CHAT ROUTES
     Route::post('add-chat-log', [App\Http\Controllers\User\LogChatController::class, 'addChatLog'])->name('addChatLog');
     
     //DAILY PLAN ROUTES
     Route::post('add-daily-task', [App\Http\Controllers\User\DailyPlanController::class, 'addDailyTask'])->name('addDailyTask');
     Route::post('edit-daily-task', [App\Http\Controllers\User\DailyPlanController::class, 'editDailyTask'])->name('editDailyTask');
     Route::post('delete-daily-task', [App\Http\Controllers\User\DailyPlanController::class, 'deleteDailyTask'])->name('deleteDailyTask');
     Route::post('complete-daily-task', [App\Http\Controllers\User\DailyPlanController::class, 'completeDailyTask'])->name('completeDailyTask');


     //TEAM SECTION ROUTES
     Route::get('my-team', [App\Http\Controllers\User\MyTeamController::class, 'my_team'])->name('my_team');
     Route::get('team-list', [App\Http\Controllers\User\MyTeamController::class, 'teamListing'])->name('teamListing');
     Route::get('team-goal', [App\Http\Controllers\User\MyTeamController::class, 'teamGoal'])->name('teamGoal');
     Route::get('team-members', [App\Http\Controllers\User\MyTeamController::class, 'teamMembers'])->name('teamMembers');
     Route::post('leave-team', [App\Http\Controllers\User\MyTeamController::class, 'leaveTeam'])->name('leaveTeam');
     Route::post('join-team', [App\Http\Controllers\User\MyTeamController::class, 'joinTeam'])->name('joinTeam');
     Route::post('delete-teammate', [App\Http\Controllers\User\MyTeamController::class, 'deleteTeamMate'])->name('deleteTeamMate');
     Route::post('get-team-members-details', [App\Http\Controllers\User\MyTeamController::class, 'getTeamMemberDetails'])->name('getTeamMemberDetails');

     //SCHEDULED SECTION ROUTES
     Route::get('scheduled', [App\Http\Controllers\User\ScheduledController::class, 'scheduled'])->name('scheduled');
     Route::get('get-listing', [App\Http\Controllers\User\ScheduledController::class, 'getListing'])->name('getListing');

     //LOGGED CONNECTION SECTION ROUTES
     Route::get('logged-connections', [App\Http\Controllers\User\LoggedConnectionController::class, 'loggedConnection'])->name('logged_connection');
     Route::post('filter-connections', [App\Http\Controllers\User\LoggedConnectionController::class, 'filterConnection'])->name('filter_connection');
     Route::post('delete-logged-connections', [App\Http\Controllers\User\LoggedConnectionController::class, 'deleteLoggedConnection'])->name('deleteLoggedConnection');

     //BLOG SECTION ROUTES
     Route::get('blog', [App\Http\Controllers\User\BlogController::class, 'blog'])->name('blog');
     Route::get('read-blog/{id}', [App\Http\Controllers\User\BlogController::class, 'readBlog'])->name('readBlog');
     Route::get('search-blog', [App\Http\Controllers\User\BlogController::class, 'searchBlog'])->name('searchBlog');

     //CHATAVIRSITY SECTION ROUTES
     Route::get('chatavirsity', [App\Http\Controllers\User\ChatavirsityController::class, 'chatavirsity'])->name('chatavirsity');
     Route::get('read-chatavirsity/{id}', [App\Http\Controllers\User\ChatavirsityController::class, 'readChatavirsity'])->name('readChatavirsity');
     Route::get('search-chatavirsity', [App\Http\Controllers\User\ChatavirsityController::class, 'searchChatavirsity'])->name('searchChatavirsity');


     //SETTING SECTION ROUTES
     Route::get('setting', [App\Http\Controllers\User\SettingController::class, 'setting'])->name('setting');
     Route::post('setting-page', [App\Http\Controllers\User\SettingController::class, 'setting_page'])->name('setting_page');
     Route::post('change_password', [App\Http\Controllers\User\SettingController::class, 'change_password'])->name('change_password');
     Route::post('change-password-post', [App\Http\Controllers\User\SettingController::class, 'change_password_post'])->name('change_password_post');
     Route::get('faq', [App\Http\Controllers\User\SettingController::class, 'faq'])->name('faq');
     Route::post('contact-us', [App\Http\Controllers\User\SettingController::class, 'contactUs'])->name('contactUs');
     Route::get('logout', [App\Http\Controllers\User\SettingController::class, 'logout'])->name('logout');
});
